<?php

/* is this an api request? If yes set a few defaults */
if (isset($_REQUEST['api']))
{
    echo '[API HAS BEEN MOVED, PLEASE <a href="api.' . SITE_CONFIG_PAGE_EXTENSION . '">GO HERE</a> FOR MORE INFORMATION]';
    exit;
}



/* validate any submission */
if ((int) $_REQUEST['submitted'])
{
    if(SITE_CONFIG_GUEST_USERS_CREATE_URLS == 'no' && $Auth->loggedIn == false)
    {
        redirect(WEB_ROOT . '/register.'.SITE_CONFIG_PAGE_EXTENSION.'?error='.urlencode(t('url_generation_limited_to_registered_users_only', 'Sorry, but you must have an account to create short urls on this site.')));   
    }
    $longUrl = trim($_REQUEST['longUrl']);
    if (SITE_CONFIG_CREATE_URL_SHOW_TERMS_CHECKBOX == 'Show')
    {
        $agreeTerms = trim($_REQUEST['agreeTerms']);
    }
    $isPrivate  = (int) $_REQUEST['shortUrlType'];
    $password   = trim($_REQUEST['shortUrlPassword']);
    $expiryDate = trim($_REQUEST['shortUrlExpiryDate']);
    $totalUses  = (int) $_REQUEST['shortUrlUses'];
    $customUrl  = shortUrl::prepareShortUrlPart($_REQUEST['customUrl']);
    $shortUrlDomain = (int)$_REQUEST['shortUrlDomain'];
    $shortUrlFolder = null;
    if(isset($_REQUEST['shortUrlFolder']))
    {
        $shortUrlFolder = (int)$_REQUEST['shortUrlFolder'];
    }

    // make sure the user owns this folder
    if(($folderListing) && ($shortUrlFolder))
    {
        $found = false;
        foreach($folderListing AS $folderItem)
        {
            if($folderItem['id'] == $shortUrlFolder)
            {
                $found = true;
            }
        }
        
        if($found == false)
        {
            $shortUrlFolder = null;
        }
    }

    $longUrls = str_replace("\r", "\n", $longUrl);
    $longUrls = str_replace("\n\n", "\n", $longUrls);
    $longUrls = explode("\n", $longUrls);
    for ($i        = 0; $i < COUNT($longUrls); $i++)
    {
        $longUrls[$i] = shortUrl::standardiseUrl($longUrls[$i]);
    }

    /* check url structure */
    if ((!(int) $agreeTerms) && (SITE_CONFIG_CREATE_URL_SHOW_TERMS_CHECKBOX == 'Show'))
    {
        setError(t("please_agree_terms_and_conditions"));
    }
    /* check to see if they have been banned from the site for creating urls ($bannedIP setup in includes/master.inc.php) */
    elseif (strtolower($bannedIP) == "creating urls")
    {
        setError(t("not_permitted_to_create_urls_on_site"));
    }
    elseif ($expiryDate)
    {
        if (!dater($expiryDate))
        {
            setError(t("date_entered_is_incorrect"));
        }
    }

    if (strlen($customUrl))
    {
        /* check custom url does not already exist */
        for ($i = 0; $i < COUNT($longUrls); $i++)
        {
            $tmpCustomUrl = $customUrl;
            if ($i > 0)
            {
                $tmpCustomUrl = $customUrl . ($i + 1);
            }

            if ($shortUrlObj = shortUrl::loadByUrl($tmpCustomUrl))
            {
                setError(t("custom_short_url_already_exits"));
            }
        }
    }

    // check structure of all urls and make sure the user isn't doing it for this site
    if (!isErrors())
    {
        for ($i = 0; $i < COUNT($longUrls); $i++)
        {
            if (!isValidUrl($longUrls[$i]))
            {
                setError(t("error_with_urls", "There was an error with 1 or more of the urls you supplied, please check and try again."));
            }
            /* check that they are not using the site url to restrict infinate loops */
            elseif (substr(strtolower($longUrls[$i]), 0, strlen(WEB_ROOT)) == strtolower(WEB_ROOT))
            {
                setError(t("can_not_create_url_on_this_site"));
            }
        }
    }

    if (!isErrors())
    {
        // don't do this for API requests
        if (!isset($_REQUEST['api']))
        {
            // only if captcha is configured
            if ((useCaptcha() == true) && (SITE_CONFIG_CAPTCHA_GUESTS_ONLY == 'yes'))
            {
                /* do we require captcha validation? */
                $showCaptcha = false;
                if (!isset($_REQUEST['g-recaptcha-response']))
                {
                    $showCaptcha = true;
                }

                /* check captcha */
                if (isset($_REQUEST['g-recaptcha-response']))
                {
                    $resp = verifyCaptcha($_POST["g-recaptcha-response"]);
                    if ($resp == false)
                    {
                        setError(t("invalid_captcha", "Captcha confirmation text is invalid."));
                        $showCaptcha = true;
                    }
                }

                if ($showCaptcha == true)
                {
                    include_once('captcha.inc.php');
                    exit;
                }
            }
        }
    }

    // check urls on Google Safe Browsing
    if (!isErrors())
    {
        // only do this is we have the key
        if (strlen(SITE_CONFIG_MALWARE_GOOGLE_SAFE_API_KEY))
        {
            $failedUrl = null;
            for ($i         = 0; $i < COUNT($longUrls); $i++)
            {
                if (domainIsGoogleSafe($longUrls[$i]) === false)
                {
                    $failedUrl = $longUrls[$i];
                }
            }

            if ($failedUrl !== null)
            {
                setError(t("url_is_malware_or_phishing", "One or more of the sites you have entered may contain malicious code or be a forgery or imitation of another website, designed to trick users into sharing personal or financial information. Please remove or try a different url."));
            }
        }
    }

    // check urls on Phishtank
    if (!isErrors())
    {
        // only do this is we have the key
        if (strlen(SITE_CONFIG_MALWARE_PHISHTANK_API_KEY))
        {
            $failedUrl = null;
            for ($i         = 0; $i < COUNT($longUrls); $i++)
            {
                if (domainIsPhishtankSafe($longUrls[$i]) === false)
                {
                    $failedUrl = $longUrls[$i];
                }
            }

            if ($failedUrl !== null)
            {
                setError(t("url_is_malware_or_phishing", "One or more of the sites you have entered may contain malicious code or be a forgery or imitation of another website, designed to trick users into sharing personal or financial information. Please remove or try a different url."));
            }
        }
    }
    
    // double check base url can be used for logged in user
    if (!isErrors())
    {
		foreach($shortUrlDomains AS $k=>$shortUrlDomainItem)
		{
			if($shortUrlDomain == 0)
			{
				$shortUrlDomain = $k;
			}
		}

		$domainInfo = $shortUrlDomains[$shortUrlDomain];

		// disabled item
		$unavailable = false;
		if(($domainInfo['premium_only'] == 1) && ($Auth->level == 'guest'))
		{
			$unavailable = true;
		}
		elseif(($domainInfo['premium_only'] == 2) && (in_array($Auth->level, array('guest', 'free user', 'user'))))
		{
			$unavailable = true;
		}

		if($unavailable == true)
		{
			setError(t("can_not_use_base_domain_for_short_url", "You can use that base url for creating short urls. Please signin for more options."));
		}
    }

    /* create the short urls */
    if (!isErrors())
    {
        $urlIds = array();
        $shortUrls = array();
        $batchTime = time();
        for ($i         = 0; $i < COUNT($longUrls); $i++)
        {
            $tmpCustomUrl = $customUrl;
            if (strlen($customUrl))
            {
                if ($i > 0)
                {
                    $tmpCustomUrl = $customUrl . ($i + 1);
                }
            }

            $shortUrlObj = new shortUrl($longUrls[$i]);
            $shortUrlObj->isPrivate = (int) $isPrivate;
            if ($password)
            {
                $password = MD5($password);
            }
            else
            {
                $password = null;
            }
            $shortUrlObj->password = $password;
            $shortUrlObj->expiryDate = null;
            if ($expiryDate)
            {
                $shortUrlObj->expiryDate = dater($expiryDate, "Y-m-d 23:59:59");
            }
            $shortUrlObj->totalUses = (int) $totalUses;
            
            $shortUrlObj->shortUrlFolder = null;
            if($shortUrlFolder)
            {
                $shortUrlObj->shortUrlFolder = (int)$shortUrlFolder;
            }

            // add user id if user is logged in
            if ($Auth->loggedIn())
            {
                $shortUrlObj->userId = (int) $Auth->id;
            }
            elseif (((int) $_REQUEST['api']) && (isset($_REQUEST['key'])))
            {
                /* lookup user account if api key passed */
                $user = UserPeer::loadUserByAPIKey(trim($_REQUEST['key']));
                if ($user)
                {
                    $shortUrlObj->userId = (int) $user->id;
                }
            }
            
            // base domain
            $shortUrlObj->urlDomainId = $shortUrlDomain;

            if (!$newShortUrl = $shortUrlObj->createShortUrl($tmpCustomUrl, $batchTime))
            {
                //setError(t("problem_creating_short_url"));
            }
            else
            {
                // do any plugin includes
                pluginHelper::includeAppends('index_additional_option_process.php', array('shortUrlObj' => $newShortUrl, 'Auth'=>$Auth));

                $urlIds[]    = $newShortUrl->id;
                $shortUrls[] = $shortUrlObj->compileShortUrl();
                unset($shortUrlObj);
            }
        }

        if (COUNT($urlIds))
        {
            /* if this is a twitter link, redirect remote */
            if ((int) $_REQUEST['postToTwitter'])
            {
                redirect("http://twitter.com/intent/tweet?text=" . rawurlencode(implode(", ", $shortUrls)));
            }
            /* if this is an api request, just return the text */
            elseif (((int) $_REQUEST['api']) && ((int) $_REQUEST['return_url_text']))
            {
                echo implode("|", $shortUrls);
                exit;
            }
            /* normal */
            else
            {
                redirect(WEB_ROOT . "/viewUrl." . SITE_CONFIG_PAGE_EXTENSION . "?u=" . implode("|", $urlIds));
            }
        }
        else
        {
            setError(t("problem_creating_short_url"));
        }
    }
}
