<?php
/* setup includes */
require_once('includes/master.inc.php');

/* require login */
$Auth->requireUser('login.php');

/* setup status list */
$statusDetails = array('active', 'expired', 'disabled', 'spam');

/* default */
$filterByStatus = 'active';
$filterByFolder = null;
if(isset($_REQUEST['filterByFolder']))
{
    $filterByFolder = (int)$_REQUEST['filterByFolder'];
}

/* delete url */
if (isset($_REQUEST['d']))
{
    $url = shortUrl::loadById($_REQUEST['d']);
    if ($url)
    {
        /* check user id */
        if ($url->userId == $Auth->id)
        {
            // delete statistics for url
            $db->query("DELETE FROM stats WHERE page_title = ".$url->id);

            // delete url
            $db->query("DELETE FROM shorturl WHERE id = ".$url->id." LIMIT 1");
            
            // set success message
            setSuccess(t("url_permanently_deleted_success_message", "The short url has been permanently deleted."));
        }
    }
}

// get folder listing
$folderListing = $db->getRows("SELECT id, folder_name, (SELECT COUNT(id) AS total FROM shorturl WHERE shorturl.shortUrlFolder = shorturl_folder.id) AS total_urls FROM shorturl_folder WHERE user_id = ".$Auth->id." ORDER BY folder_name");

/* setup page */
define("PAGE_NAME", t("account_home_page_name", "Account Home"));
define("PAGE_DESCRIPTION", t("account_home_meta_description", "Your Account Home"));
define("PAGE_KEYWORDS", t("account_home_meta_keywords", "account, home, shorturl, your, interface, short, url, site"));
define("SITE_SELECTED_PAGE", "account_home");

require_once('_header.php');

// load all short urls for this account
$sQL = 'SELECT COUNT(id) AS total FROM shorturl WHERE userId = ' . $db->quote($Auth->id) . ' AND status=\'active\' ';
$urlTotal = (int)$db->getValue($sQL);
?>

<script>
    $=jQuery;
    oTable = null;
    $(document).ready(function() {
        oTable = $('#shortUrlData').dataTable( {
            "sPaginationType": "full_numbers",
            "aaSorting": [[ 1, "asc" ]],
            "bAutoWidth": false,
            "aoColumns": [
                { "bSortable": false, sClass: "alignCenter mobileHide" },
                { "bSortable": true},
                { "bSortable": true, sClass: "alignCenter mobileHide tabletHide" },
                { "bSortable": true, sClass: "alignCenter mobileHide" },
                { "bSortable": false, sClass: "alignCenter mobileHide" },
                { "bSortable": false, sClass: "alignCenter" }
            ],
            "bServerSide": true,
            "bProcessing": true,
            "sAjaxSource": '_account_home.ajax.php',
            "fnRowCallback": function(nRow, aData, iDisplayIndex, iDisplayIndexFull) {
                cellContents = aData[4];
                if (cellContents.substr(0,7) == 'expired')
                {
                    $(nRow).addClass('rowUrlExpired');
                }
                return nRow;
            },
            "fnServerData": function ( sSource, aoData, fnCallback ) {
                aoData.push( { "name": "filterText", "value": $('#filterText').val() } );
                aoData.push( { "name": "filterByStatus", "value": $('#filterByStatus').val() } );
                aoData.push( { "name": "filterByFolder", "value": $('#filterByFolder').val() } );
                $.ajax({
                    "dataType": 'json',
                    "type": "GET",
                    "url": "_account_home.ajax.php",
                    "data": aoData,
                    "success": fnCallback
                });
            },
            "oLanguage": {
                "oPaginate": {
                    "sFirst": "<?php echo safeOutputToScreen(t('paging_first', 'First')); ?>",
                    "sLast": "<?php echo safeOutputToScreen(t('paging_last', 'Last')); ?>",
                    "sNext": "<?php echo safeOutputToScreen(t('paging_next', 'Next')); ?>",
                    "sPrevious": "<?php echo safeOutputToScreen(t('paging_previous', 'Previous')); ?>"
                },
                "sEmptyTable": "<?php echo safeOutputToScreen(t('datatable_empty', 'No data found.')); ?>",
                "sInfo": "<?php echo safeOutputToScreen(t('datatable_data_info', 'Showing _START_ to _END_ of _TOTAL_ entries')); ?>",
                "sLengthMenu": "<?php echo safeOutputToScreen(t('datatable_per_page', 'Show _MENU_ entries')); ?>"
            }
        } );
        
        // update custom filter
        $('.dataTables_filter').html($('#customFilter').html());
    } );
    
    function reloadTable()
    {
        oTable.fnDraw();
    }
</script>

<div class="span12">
    <?php
    if (isSuccess())
    {
        echo outputSuccess();
    }
    elseif (isErrors())
    {
        echo outputErrors();
    }
    ?>
    <p>
        <?php if ($urlTotal): ?>
            <?php echo t('you_have_x_urls_within_your_account', 'You have [[[TOTAL_URLS]]] url[[[URL_S]]] within your account. Use the table below to navigate or search for short urls you\'ve previously created. <a href="index.[[[SITE_CONFIG_PAGE_EXTENSION]]]">Click here</a> to create a new short url.', array('TOTAL_URLS'=>$urlTotal, 'URL_S'=>(($urlTotal != 1) ? 's' : ''), 'SITE_CONFIG_PAGE_EXTENSION'=>SITE_CONFIG_PAGE_EXTENSION)); ?>
        <?php else: ?>
            <?php echo t('you_have_no_urls_within_your_account', 'You have no urls within your account. <a href="index.[[[SITE_CONFIG_PAGE_EXTENSION]]]">Click here</a> to create a new short url.', array('SITE_CONFIG_PAGE_EXTENSION'=>SITE_CONFIG_PAGE_EXTENSION)); ?>
        <?php endif; ?>

        <br/>
    </p>
    <div class="clear"><!-- --></div>

    <div class="accountHomeWrapper">
        <p class="introText">
            <?php
            if ($urlTotal)
            {
                echo '<table id="shortUrlData" class="table table-bordered table-striped" width="100%" cellpadding="3" cellspacing="0">';
                echo '<thead>';
                echo '<th style="width: 30px;" class="ui-state-default"></th>';
                echo '<th class="ui-state-default">'.t('short_original_url', 'Short/Original Url:').'</th>';
                echo '<th  style="width: 135px; text-align: center;"class="ui-state-default">'.t('created_last_visited', 'Created/Last Visited:').'</th>';
                echo '<th style="width: 55px; text-align: center;" class="ui-state-default">'.t('visits', 'Visits:').'</th>';
                echo '<th style="width: 65px; text-align: center;" class="ui-state-default">'.t('status', 'Status:').'</th>';
                echo '<th style="width: 90px; text-align: center;" class="ui-state-default">'.t('options', 'Options:').'</th>';
                echo '</thead>';
                echo '<tbody>';
                echo '</tbody>';
                echo '</table>';
            }
            ?>
        </p>
        <div class="clear"></div>
    </div>
    <?php if($urlTotal >= 1): ?>
    <span style="float:right;">
        <form action="export_urls.php" method="post">
            <button type="submit" name="submit" class="btn btn-primary" tabindex="99"><?php echo t("export_url_data", "export url data"); ?></button>
        </form>
    </span>
    <?php endif; ?>
    <div class="buttonWrapper" style="float: left; margin-right: 10px;">
        <form method="POST" action="account_folder.html">
            <button type="submit" name="submit" class="btn btn-primary" tabindex="99"><?php echo t("manage_folders", "manage folders"); ?></button>
        </form>
    </div>
    <div class="buttonWrapper">
        <form method="POST" action="account_folder_add.html">
            <button type="submit" name="submit" class="btn btn-primary" tabindex="99"><?php echo t("add_folder", "add folder"); ?></button>
        </form>
    
    <div class="clear"></div>
</div>

<div class="customFilter" id="customFilter" style="display: none;">
    <div class="filterItem filterText">
        <label for="filterText">
            <?php echo t('filter_results', 'Filter Results'); ?>:
        </label>
        <input name="filterText" id="filterText" type="text" value="<?php echo safeOutputToScreen($filterText); ?>" onKeyUp="reloadTable(); return false;" style="width: 160px;"/>
    </div>
    <div class="filterItem mobileHide">
        <label for="filterByStatus">
            <?php echo t('by_status', 'By Status'); ?>:
        </label>
        <select name="filterByStatus" id="filterByStatus" onChange="reloadTable(); return false;" style="width: 120px;">
            <option value="">- <?php echo t('all', 'all'); ?> -</option>
            <?php
            if (COUNT($statusDetails))
            {
                foreach ($statusDetails AS $statusDetail)
                {
                    echo '<option value="' . $statusDetail . '"';
                    if (($filterByStatus) && ($filterByStatus == $statusDetail))
                    {
                        echo ' SELECTED';
                    }
                    echo '>' . UCWords(t($statusDetail, $statusDetail)) . '</option>';
                }
            }
            ?>
        </select>
    </div>
    <div class="filterItem mobileHide">
        <label for="filterByFolder">
            <?php echo t('by_folder', 'By Folder'); ?>:
        </label>
        <select name="filterByFolder" id="filterByFolder" onChange="reloadTable(); return false;" style="width: 140px;">
            <option value="">- <?php echo t('all', 'all'); ?> -</option>
            <?php
            if (COUNT($folderListing))
            {
                foreach ($folderListing AS $folderListingItem)
                {
                    echo '<option value="' . $folderListingItem['id'] . '"';
                    if (($filterByFolder) && ($folderListingItem['id'] == $filterByFolder))
                    {
                        echo ' SELECTED';
                    }
                    echo '>' . $folderListingItem['folder_name'] . ' (' . $folderListingItem['total_urls'] . ')</option>';
                }
            }
            ?>
        </select>
    </div>
    <div class="clear"></div>
</div>

<?php
require_once('_footer.php');
?>