<?php
/* setup includes */
require_once('includes/master.inc.php');

/* require login */
$Auth->requireUser('login.php');

/* load user */
$user = UserPeer::loadUserById($Auth->id);
if (!$user)
{
    redirect(WEB_ROOT);
}

// make sure this user owns the short url
$urlId    = (int) $_REQUEST['id'];
$shortUrl = ShortUrl::loadById($urlId);
if ($shortUrl->userId != $user->id)
{
    redirect(WEB_ROOT);
}

// stop users from un-spamming their urls
if ($shortUrl->status == 'spam')
{
    redirect(WEB_ROOT);
}

//setup defaults
$shortUrlStatusList = array('active', 'expired', 'disabled');
$original_url       = $shortUrl->fullUrl;
$shortUrlFolder     = $shortUrl->shortUrlFolder;
$folderListing      = $db->getRows("SELECT id, folder_name FROM shorturl_folder WHERE user_id = " . $Auth->id . " ORDER BY folder_name");

/* setup page */
define("PAGE_NAME", t("url_edit_page_name", "Edit Url"));
define("PAGE_DESCRIPTION", t("url_edit_meta_description", "Edit Url"));
define("PAGE_KEYWORDS", t("url_edit_meta_keywords", "details, account, short, url, user"));
define("SITE_SELECTED_PAGE", "account_home");

/* update user */
if ((int) $_REQUEST['submitme'])
{
    // validation
    $original_url = trim($_REQUEST['original_url']);
    $original_url = strip_tags($original_url);
    $original_url = str_replace("\n", "", $original_url);
    $original_url = str_replace("\r", "", $original_url);
    $status       = trim($_REQUEST['status']);

    $shortUrlFolder = null;
    if ((int) $_REQUEST['shortUrlFolder'])
    {
        $shortUrlFolder = $_REQUEST['shortUrlFolder'];
    }
    // make sure the user owns this folder
    if (($folderListing) && ($shortUrlFolder))
    {
        $found = false;
        foreach ($folderListing AS $folderItem)
        {
            if ($folderItem['id'] == $shortUrlFolder)
            {
                $found = true;
            }
        }

        if ($found == false)
        {
            $shortUrlFolder = null;
        }
    }

    if (!strlen($original_url))
    {
        setError(t("please_enter_the_long_url", "Please enter the long url"));
    }
    elseif (!in_array($status, $shortUrlStatusList))
    {
        setError(t("invalid_status_used", "Please select a valid status"));
    }
    elseif (_CONFIG_DEMO_MODE == true)
    {
        setError(t("no_changes_in_demo_mode"));
    }
    else
    {
        if (!isValidUrl($original_url))
        {
            setError(t("error_with_urls", "There was an error with the url you supplied, please check and try again."));
        }
        /* check that they are not using the site url to restrict infinate loops */
        elseif (substr(strtolower($original_url), 0, strlen(WEB_ROOT)) == strtolower(WEB_ROOT))
        {
            setError(t("can_not_create_url_on_this_site"));
        }
    }

    // update the account
    if (!isErrors())
    {
        $db = Database::getDatabase(true);
        $rs = $db->query('UPDATE shorturl SET originalUrl = :originalUrl, status = :status, expiryDate=null, shortUrlFolder=:shortUrlFolder WHERE id = :id', array('originalUrl'    => $original_url, 'status'         => $status, 'shortUrlFolder' => $shortUrlFolder, 'id'             => $urlId));
        if ($rs)
        {
            setSuccess(t("url_edit_updated_success_message", "Url details successfully updated, <a href='[[[YOUR_URLS_LINK]]]'>click here</a> to go to your urls.", array('YOUR_URLS_LINK' => WEB_ROOT . '/account_home.' . SITE_CONFIG_PAGE_EXTENSION)));
        }
        else
        {
            setError(t("problem_updating_the_url_try_again_later", "There was a problem updating the url, please try again later"));
        }
    }
}

require_once('_header.php');
?>

<div class="span9 page_sidebar accountDetails">

    <?php
    if (isSuccess())
    {
        echo outputSuccess();
    }
    elseif (isErrors())
    {
        echo outputErrors();
    }
    ?>

    <div class="well">
        <h5><?php echo t("url_details", "Url Details"); ?></h5>
        <hr/>
        <p>
            <?php echo t('user_the_form_below_to_amend_the_url', 'Use the form below to amend the short url.'); ?>
        </p>
        <form method="post" action="<?php echo WEB_ROOT; ?>/account_url_edit.<?php echo SITE_CONFIG_PAGE_EXTENSION; ?>" class="form">
            <div>
                <label for="original_url">
                    <?php echo t("long_url", "Long Url"); ?>:
                </label>
                <textarea id="original_url" name="original_url" tabindex="1"><?php echo safeOutputToScreen($original_url); ?></textarea>
            </div>
            <div class="clear"></div>

            <div class="third">
                <label for="status">
                    <?php echo t("status", "Status"); ?>:
                </label>
                <select autofocus="autofocus" tabindex="2" id="status" name="status">
                    <?php foreach ($shortUrlStatusList AS $shortUrlStatusItem): ?>
                        <option value="<?php echo $shortUrlStatusItem; ?>" <?php echo ($status == $shortUrlStatusItem) ? 'SELECTED' : ''; ?>><?php echo UCWords(t($shortUrlStatusItem, $shortUrlStatusItem)); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="third">
                <label for="shortUrlFolder"><?php echo t("index_save_to_folder", "Save To Folder"); ?>:</label>
                <select id="shortUrlFolder" name="shortUrlFolder">
                    <option value="">- <?php echo t('none', 'none'); ?>-</option>
                    <?php
                    foreach ($folderListing AS $folderItem)
                    {
                        echo '<option value="' . $folderItem['id'] . '"';
                        if ($folderItem['id'] == (int) $shortUrlFolder)
                        {
                            echo ' SELECTED';
                        }
                        echo '>' . $folderItem['folder_name'] . '</option>';
                    }
                    ?>
                </select>
            </div>

            <div class="clear" style="padding-bottom: 18px;"></div>

            <div class="buttonWrapper">
                <button type="submit" name="submit" class="btn btn-primary" tabindex="99"><?php echo t("update_url", "update url"); ?></button>
            </div>
            <div class="clear"></div>

            <input type="hidden" value="1" name="submitme"/>
            <input type="hidden" value="<?php echo $urlId; ?>" name="id"/>
        </form>
    </div>
</div>
<?php include_once("_bannerRightContent.inc.php"); ?>

<?php
require_once('_footer.php');
?>