<?php
/* setup includes */
require_once('includes/master.inc.php');

/* make sure we have permission to view the api */
if (SITE_CONFIG_ENABLE_API == 'no')
{
    redirect('http://' . _CONFIG_SITE_FULL_URL);
}

/* load user for api key */
$apiKey = '';
$demoApiKey = MD5(time());
if ($Auth->loggedIn())
{
    $user = UserPeer::loadUserById($Auth->id);
    if (!$user)
    {
        redirect(WEB_ROOT);
    }

    $apiKey = trim($user->apikey);
    if ((strlen($apiKey) == 0) || (isset($_REQUEST['rapi'])))
    {
        // create api key
        $apiKey = UserPeer::createApiKey();

        // save in db
        $db->query('UPDATE users SET apikey = :apikey WHERE id = :id', array('apikey' => $apiKey, 'id'     => $Auth->id));
    }
    
    $demoApiKey = $apiKey;
}

// setup API path
$apiPath = str_replace(_CONFIG_SITE_PROTOCOL.'://'._CONFIG_SITE_HOST_URL, "", WEB_ROOT);
if(substr($apiPath, 0, 1) != '/')
{
    $apiPath = '/'.$apiPath;
}
$apiPath .= '/api/v1/'.$demoApiKey.'/shorturl';
define("API_PATH", $apiPath);

/* setup page */
define("PAGE_NAME", t("api_page_name", "API"));
define("PAGE_DESCRIPTION", t("api_meta_description", "Our Free API"));
define("PAGE_KEYWORDS", t("api_meta_keywords", "api, application, programming, interface, short, url, site"));
define("SITE_SELECTED_PAGE", "tools");

require_once('_header.php');
?>

<div class="span12">
    <div class="row">
        <div class="span3 page_sidebar">
            <?php include_once('_tools_left_nav.inc.php'); ?>
        </div>
        <div class="span9 api_docs">
            <h4><?php echo t('overview', 'Overview'); ?></h4>
            <p>
                <?php echo t('api_overview_intro', 'Our API allows you to provide short url functionality to any of your existing websites. When you register for an account, you\'re generated a unique API key which should be used in the API calls listed below.'); ?>
            </p>
            <p>
                <?php echo t('api_overview_intro_2', 'The examples below generate responses in json but you can also use xml by replacing the end of the url call with .xml.'); ?>
            </p>
            <hr>

            <a name="createBasic"></a>
            <h4><?php echo UCWords(t('create', 'Create')); ?></h4>
            <p>
                <?php echo t('api_create_a_new_short_url_providing_a_base64_encoded_version_of_the_original_url', 'Create a new short url providing a base64 encoded version of the original long url.'); ?>
            </p>
            <h5><?php echo t('parameters', 'Parameters'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">key</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('your_api_access_key', 'Your API access key.'); ?> <?php echo strlen($apiKey)?'<code>('.$apiKey.')</code>':t('login_to_view', 'Login to view.'); ?></td>
                    </tr>
                    <tr>
                        <td>url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('base64_encoded_version_of_your_long_url', 'Base64 encoded version of your long url. <code>base64_encode()</code> in PHP.'); ?></td>
                    </tr>
                </tbody>
            </table>
            <h5><?php echo t('return_values', 'Return Values'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">url_id</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('integer', 'integer')); ?></td>
                        <td><?php echo t('unique_url_id', 'Unique url id.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_including_domain_name', 'Short url including domain name.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url_part</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_part_excluding_domain_name', 'Short url part. (excluding domain name)'); ?></td>
                    </tr>
                    <tr>
                        <td>original_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('the_original_decoded_long_url', 'The original decoded long url.'); ?></td>
                    </tr>
                    <tr>
                        <td>date_time</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('date_and_time_of_the_api_call_in_the_format', 'Date and time of the API call. In the format yyyy-mm-dd hh:mm:ss.'); ?></td>
                    </tr>
                </tbody>
            </table>
            
            <h5><?php echo t('example_request', 'Example Request'); ?>:</h5>
            <pre><?php echo t('api_address', 'API Address'); ?>: <?php echo _CONFIG_SITE_PROTOCOL; ?>://<?php echo _CONFIG_SITE_HOST_URL; ?><br/>GET <?php echo API_PATH; ?>/create/url/<strong>BASE64_ENCODED_LONG_URL</strong>.json</pre>
            
            <h5><?php echo t('example_response', 'Example Response'); ?>:</h5>
            <pre>{
   "code":200,
   "data":{
      "url_id":"1388597",
      "short_url":"<?php echo WEB_ROOT; ?>/srt",
      "short_url_part":"srt",
      "original_url":"http://www.bbc.co.uk",
      "date_time":"2013-04-04 16:18:05"
   }
}</pre>
            <hr>
            
            <a name="createOptions"></a>
            <h4><?php echo UCWords(t('create_additional_options', 'Create (Additional Options)')); ?></h4>
            <p><?php echo t('create_a_new_short_url_including_some_additional_settings', 'Create a new short url including some additional settings such as a custom short url, password to access and an expiry date.'); ?>
            </p>
            <h5><?php echo t('parameters', 'Parameters'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">key</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('your_api_access_key', 'Your API access key.'); ?> <?php echo strlen($apiKey)?'<code>('.$apiKey.')</code>':t('login_to_view', 'Login to view.'); ?></td>
                    </tr>
                    <tr>
                        <td>url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('base64_encoded_version_of_your_long_url', 'Base64 encoded version of your long url. <code>base64_encode()</code> in PHP.'); ?></td>
                    </tr>
                    <tr>
                        <td>custom_url (<?php echo t('optional', 'optional'); ?>)</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('custom_short_url', 'Custom short url part.'); ?></td>
                    </tr>
                    <tr>
                        <td>password (<?php echo t('optional', 'optional'); ?>)</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('password_to_access_url', 'Password to access url.'); ?></td>
                    </tr>
                    <tr>
                        <td>expiry_date (<?php echo t('optional', 'optional'); ?>)</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('expiry_date_in_the_format', 'Date to expire the url. In the format yyyy-mm-dd.'); ?></td>
                    </tr>
                    <tr>
                        <td>base_domain (<?php echo t('optional', 'optional'); ?>)</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('base_domain_url', 'Url to use for the short url. Must already exist on the site. No http or trailing forward slash. i.e. domain.com'); ?></td>
                    </tr>
                </tbody>
            </table>
            <h5><?php echo t('return_values', 'Return Values'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">url_id</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('integer', 'integer')); ?></td>
                        <td><?php echo t('unique_url_id', 'Unique url id.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_including_domain_name', 'Short url including domain name.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url_part</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_part_excluding_domain_name', 'Short url part. (excluding domain name)'); ?></td>
                    </tr>
                    <tr>
                        <td>original_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('the_original_decoded_long_url', 'The original decoded long url.'); ?></td>
                    </tr>
                    <tr>
                        <td>date_time</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('date_and_time_of_the_api_call_in_the_format', 'Date and time of the API call. In the format yyyy-mm-dd hh:mm:ss.'); ?></td>
                    </tr>
                </tbody>
            </table>
            
            <h5><?php echo t('example_request', 'Example Request'); ?>:</h5>
            <pre><?php echo t('api_address', 'API Address'); ?>: <?php echo _CONFIG_SITE_PROTOCOL; ?>://<?php echo _CONFIG_SITE_HOST_URL; ?><br/>GET <?php echo API_PATH; ?>/create/custom_url/<strong>CUSTOM_SHORT_URL</strong>/password/<strong>PASSWORD_TO_ACCESS</strong>/expiry_date/<strong>URL_EXPIRY_DATE</strong>/url/<strong>BASE64_ENCODED_LONG_URL</strong>.json</pre>
            
            <h5><?php echo t('example_response', 'Example Response'); ?>:</h5>
            <pre>{
   "code":200,
   "data":{
      "url_id":"1388598",
      "short_url":"<?php echo WEB_ROOT; ?>/bbc",
      "short_url_part":"bbc",
      "original_url":"http://www.bbc.co.uk",
      "date_time":"2013-04-04 16:18:08"
   }
}</pre>
            <hr>
            
            <a name="disable"></a>
            <h4><?php echo UCWords(t('disable', 'Disable')); ?></h4>
            <p><?php echo t('disable_an_active_short_url_within_your account', 'Disable an active short url within your account.'); ?>
            </p>
            <h5><?php echo t('parameters', 'Parameters'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">key</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('your_api_access_key', 'Your API access key.'); ?> <?php echo strlen($apiKey)?'<code>('.$apiKey.')</code>':t('login_to_view', 'Login to view.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('base64_encoded_version_of_your_short_url', 'Base64 encoded version of your short url. <code>base64_encode()</code> in PHP.'); ?></td>
                    </tr>
                </tbody>
            </table>
            <h5><?php echo t('return_values', 'Return Values'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">url_id</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('integer', 'integer')); ?></td>
                        <td><?php echo t('unique_url_id', 'Unique url id.'); ?></td>
                    </tr>
                    <tr>
                        <td>status</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_status', 'Short url status.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_including_domain_name', 'Short url including domain name.'); ?></td>
                    </tr>
                    <tr>
                        <td>date_time</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('date_and_time_of_the_api_call_in_the_format', 'Date and time of the API call. In the format yyyy-mm-dd hh:mm:ss.'); ?></td>
                    </tr>
                </tbody>
            </table>
            
            <h5><?php echo t('example_request', 'Example Request'); ?>:</h5>
            <pre><?php echo t('api_address', 'API Address'); ?>: <?php echo _CONFIG_SITE_PROTOCOL; ?>://<?php echo _CONFIG_SITE_HOST_URL; ?><br/>GET <?php echo API_PATH; ?>/disable/short_url/<strong>BASE64_ENCODED_SHORT_URL</strong>.json</pre>
            
            <h5><?php echo t('example_response', 'Example Response'); ?>:</h5>
            <pre>{
   "code":200,
   "data":{
      "url_id":"1388598",
      "status":"disabled",
      "short_url":"<?php echo WEB_ROOT; ?>/bbc",
      "date_time":"2013-04-04 17:01:42"
   }
}</pre>
            <hr>
            
            <a name="activate"></a>
            <h4><?php echo UCWords(t('activate', 'Activate')); ?></h4>
            <p><?php echo t('activate_a_disabled_short_url_within_your_account', 'Activate a disabled short url within your account.'); ?>
            </p>
            <h5><?php echo t('parameters', 'Parameters'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">key</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('your_api_access_key', 'Your API access key.'); ?> <?php echo strlen($apiKey)?'<code>('.$apiKey.')</code>':t('login_to_view', 'Login to view.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('base64_encoded_version_of_your_short_url', 'Base64 encoded version of your short url. <code>base64_encode()</code> in PHP.'); ?></td>
                    </tr>
                </tbody>
            </table>
            <h5><?php echo t('return_values', 'Return Values'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">url_id</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('integer', 'integer')); ?></td>
                        <td><?php echo t('unique_url_id', 'Unique url id.'); ?></td>
                    </tr>
                    <tr>
                        <td>status</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_status', 'Short url status.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_including_domain_name', 'Short url including domain name.'); ?></td>
                    </tr>
                    <tr>
                        <td>date_time</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('date_and_time_of_the_api_call_in_the_format', 'Date and time of the API call. In the format yyyy-mm-dd hh:mm:ss.'); ?></td>
                    </tr>
                </tbody>
            </table>
            
            <h5><?php echo t('example_request', 'Example Request'); ?>:</h5>
            <pre><?php echo t('api_address', 'API Address'); ?>: <?php echo _CONFIG_SITE_PROTOCOL; ?>://<?php echo _CONFIG_SITE_HOST_URL; ?><br/>GET <?php echo API_PATH; ?>/enable/short_url/<strong>BASE64_ENCODED_SHORT_URL</strong>.json</pre>
            
            <h5><?php echo t('example_response', 'Example Response'); ?>:</h5>
            <pre>{
   "code":200,
   "data":{
      "url_id":"1388598",
      "status":"active",
      "short_url":"<?php echo WEB_ROOT; ?>/bbc",
      "date_time":"2013-04-04 17:01:42"
   }
}</pre>
            <hr>
            
            <a name="info"></a>
            <h4><?php echo UCWords(t('info', 'Info')); ?></h4>
            <p><?php echo t('get_detailed_information_for_any_short_url_within_your_account', 'Get detailed information for any short url within your account.'); ?>
            </p>
            <h5><?php echo t('parameters', 'Parameters'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">key</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('your_api_access_key', 'Your API access key.'); ?> <?php echo strlen($apiKey)?'<code>('.$apiKey.')</code>':t('login_to_view', 'Login to view.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('base64_encoded_version_of_your_short_url', 'Base64 encoded version of your short url. <code>base64_encode()</code> in PHP.'); ?></td>
                    </tr>
                </tbody>
            </table>
            <h5><?php echo t('return_values', 'Return Values'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">url_id</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('integer', 'integer')); ?></td>
                        <td><?php echo t('unique_url_id', 'Unique url id.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_including_domain_name', 'Short url including domain name.'); ?></td>
                    </tr>
                    <tr>
                        <td>short_url_part</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_part_excluding_domain_name', 'Short url part. (excluding domain name)'); ?></td>
                    </tr>
                    <tr>
                        <td>original_url</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('the_original_decoded_long_url', 'The original decoded long url.'); ?></td>
                    </tr>
                    <tr>
                        <td>date_created</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('datetime_url_was_create', 'The date/time the short url was create.'); ?></td>
                    </tr>
                    <tr>
                        <td>last_accessed</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('datetime_url_was_last_accessed', 'The date/time the short url was last accessed.'); ?></td>
                    </tr>
                    <tr>
                        <td>total_visits</td>
                        <td class="center"><?php echo strtolower(t('integer', 'integer')); ?></td>
                        <td><?php echo t('total_visits', 'Total visits.'); ?></td>
                    </tr>
                    <tr>
                        <td>has_password</td>
                        <td class="center"><?php echo strtolower(t('bool', 'bool')); ?></td>
                        <td><?php echo t('whether_the_url_needs_a_password', 'Whether the url needs a password to access.'); ?></td>
                    </tr>
                    <tr>
                        <td>expiry_date</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('datetime_url_will_expire', 'The date/time the short url will expire.'); ?></td>
                    </tr>
                    <tr>
                        <td>status</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('short_url_status', 'Short url status.'); ?></td>
                    </tr>
                    <tr>
                        <td>date_time</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('date_and_time_of_the_api_call_in_the_format', 'Date and time of the API call. In the format yyyy-mm-dd hh:mm:ss.'); ?></td>
                    </tr>
                </tbody>
            </table>
            
            <h5><?php echo t('example_request', 'Example Request'); ?>:</h5>
            <pre><?php echo t('api_address', 'API Address'); ?>: <?php echo _CONFIG_SITE_PROTOCOL; ?>://<?php echo _CONFIG_SITE_HOST_URL; ?><br/>GET <?php echo API_PATH; ?>/info/short_url/<strong>BASE64_ENCODED_SHORT_URL</strong>.json</pre>
            
            <h5><?php echo t('example_response', 'Example Response'); ?>:</h5>
            <pre>{
   "code":200,
   "data":{
      "url_id":"13423436",
      "short_url":"<?php echo WEB_ROOT; ?>/bbc",
      "short_url_part":"bbc",
      "original_url":"http://www.bbc.co.uk",
      "date_created":"2013-04-04 12:36:09",
      "last_accessed":"2013-05-02 12:32:05",
      "total_visits":"3452",
      "has_password":true,
      "expiry_date":"2019-03-02 23:59:59",
      "status":"active",
      "date_time":"2013-04-04 17:10:14"
   }
}</pre>
            <hr>
            
            <a name="list"></a>
            <h4><?php echo UCWords(t('list', 'List')); ?></h4>
            <p><?php echo t('list_all_active_urls_within_your_account', 'List all active urls within your account.'); ?>
            </p>
            <h5><?php echo t('parameters', 'Parameters'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">key</td>
                        <td class="center" style="width: 80px;"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('your_api_access_key', 'Your API access key.'); ?> <?php echo strlen($apiKey)?'<code>('.$apiKey.')</code>':t('login_to_view', 'Login to view.'); ?></td>
                    </tr>
                </tbody>
            </table>
            <h5><?php echo t('return_values', 'Return Values'); ?>:</h5>
            <table cellpadding="3" cellspacing="0" class="table table-bordered table-striped" width="100%">
                <thead>
                    <tr>
                        <th><?php echo UCWords(t('name', 'name')); ?>:</th>
                        <th><?php echo UCWords(t('type', 'type')); ?>:</th>
                        <th><?php echo UCWords(t('description', 'description')); ?>:</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td style="width: 130px;">urls</td>
                        <td class="center"><?php echo strtolower(t('array', 'array')); ?></td>
                        <td><?php echo t('list_of_short_urls_in_account', 'List of short urls within the account.'); ?></td>
                    </tr>
                    <tr>
                        <td>date_time</td>
                        <td class="center"><?php echo strtolower(t('string', 'string')); ?></td>
                        <td><?php echo t('date_and_time_of_the_api_call_in_the_format', 'Date and time of the API call. In the format yyyy-mm-dd hh:mm:ss.'); ?></td>
                    </tr>
                </tbody>
            </table>
            
            <h5><?php echo t('example_request', 'Example Request'); ?>:</h5>
            <pre><?php echo t('api_address', 'API Address'); ?>: <?php echo _CONFIG_SITE_PROTOCOL; ?>://<?php echo _CONFIG_SITE_HOST_URL; ?><br/>GET <?php echo API_PATH; ?>/list_active_urls.json</pre>
            
            <h5><?php echo t('example_response', 'Example Response'); ?>:</h5>
            <pre>{
   "code":200,
   "data":{
      "urls":[
         {
            "short_url":"<?php echo WEB_ROOT; ?>/2F"
         },
         {
            "short_url":"<?php echo WEB_ROOT; ?>/2q"
         }
      ],
      "date_time":"2013-04-09 09:48:05"
   }
}</pre>
            <hr>
            
        </div>
    </div>
</div>


<?php
require_once('_footer.php');
?>