<?php

/* setup includes */
require_once('../includes/master.inc.php');

/**
 * Access point for all API calls
 */
set_include_path('.' . PATH_SEPARATOR .
        './library/MyApi' . PATH_SEPARATOR .
        './library/Api'
);

include("library/Api/Bootstrap.php");
include("library/MyApi/MyApi.php");

// Fix json encode for older PHP version than 5.2
include "library/Json/Encoder.php";

// Create request object
$request = new Api_Request(WEB_ROOT."/api/");
$request->setParams(array("version", "key", "service", "method"));
$request->analyze();

$config = array('v1');
$config['v1']['custom_path'] = 'MyApi';
$config['v1']['block'] = '';  // list of blocked ips, comma separated
$config['v1']['max_request_hits'] = 3;  // 5 requests every
$config['v1']['max_request_time'] = 1;  // 1 second

// Create Custom api instance
$api = new MyApi();

// Add modify config hook
$api->addHook("Api_Hook_ConfigModify", Api_Hook_IHook::HOOK_CONFIG_LOADED);
$api->addHook("Api_Hook_ApiEnabled", Api_Hook_IHook::HOOK_BEFORE_SERVICE_EXECUTE);
$api->addHook("Api_Hook_ApiKey", Api_Hook_IHook::HOOK_BEFORE_SERVICE_EXECUTE);
$api->addHook("Api_Hook_RequestLimit", Api_Hook_IHook::HOOK_BEFORE_SERVICE_EXECUTE);
$api->addHook("Api_Hook_ParserModify", Api_Hook_IHook::HOOK_MODIFY_PARSER);

// Handle api request and catch errors
try
{
    $api->handle($request, $config);
}
catch (Api_Error $error)
{
    $response = new Api_Response(
                    $error->getCode(),
                    null,
                    $error);
    $api->send($response);
}

