<?php
/* setup includes */
require_once('includes/master.inc.php');

/* setup page */
define("PAGE_NAME", t("contact_page_name", "Contact"));
define("PAGE_DESCRIPTION", t("contact_meta_description", "Contact the site admin"));
define("PAGE_KEYWORDS", t("contact_meta_keywords", "contact, account, short, url, user"));
define("SITE_SELECTED_PAGE", "contact");

// success handling
if (isset($_REQUEST['s']))
{
    setSuccess(t('contact_success', 'Thanks for submitting the contact form on our site. We\'ll review the query as soon as possible and get back to your within the next 48 hours.'));
}
/* register user */
if ((int) $_REQUEST['submitme'])
{
    // validation
    $name                = trim($_REQUEST['name']);
    $emailAddress        = trim(strtolower($_REQUEST['emailAddress']));
    $query               = trim($_REQUEST['query']);

    if (strlen($name) == 0)
    {
        setError(t("please_enter_your_name", "Please enter your name"));
    }
    elseif (strlen($emailAddress) == 0)
    {
        setError(t("please_enter_your_email_address", "Please enter your email address"));
    }
    elseif (!valid_email($emailAddress))
    {
        setError(t("your_email_address_is_invalid", "Your email address is invalid"));
    }
    elseif (strlen($query) == 0)
    {
        setError(t("your_message_is_invalid", "Your message is invalid"));
    }
    
    // check captcha
    if((!isErrors()) && (SITE_CONFIG_SHOW_CAPTCHA_ON_CONTACT_FORM == 'yes'))
    {
        if (!isset($_REQUEST['g-recaptcha-response']))
        {
            setError(t("invalid_captcha", "Captcha confirmation text is invalid."));
        }
        else
        {
            $resp = verifyCaptcha($_REQUEST["g-recaptcha-response"]);
            if ($resp == false)
            {
                setError(t("invalid_captcha", "Captcha confirmation text is invalid."));
            }
        }
    }

    if (!isErrors())
    {
        $replacements = array(
            'FULL_NAME' => $name,
            'EMAIL_ADDRESS' => $emailAddress,
            'QUERY' => nl2br($query),
            'SITE_NAME' => SITE_CONFIG_SITE_NAME,
            'WEB_ROOT' => WEB_ROOT,
            'USERS_IP' => getUsersIPAddress()
        );
        $defaultContent = "There has been a contact form submission from [[[SITE_NAME]]] with the following details:<br/><br/>";
        $defaultContent .= "***************************************<br/>";
        $defaultContent .= "Full Name: [[[FULL_NAME]]]<br/>";
        $defaultContent .= "Email Address: [[[EMAIL_ADDRESS]]]<br/><br/>";
        $defaultContent .= "[[[QUERY]]]<br/>";
        $defaultContent .= "***************************************<br/>";
        $defaultContent .= "Submitted IP: [[[USERS_IP]]]<br/>";
        $defaultContent .= "***************************************<br/><br/>";
        $htmlMsg = t('contact_email_content', $defaultContent, $replacements);

        send_html_mail(SITE_CONFIG_SITE_CONTACT_FORM_EMAIL, $subject, $htmlMsg, SITE_CONFIG_DEFAULT_EMAIL_ADDRESS_FROM, strip_tags(str_replace("<br/>", "\n", $htmlMsg)));
        redirect(WEB_ROOT . '/contact.' . SITE_CONFIG_PAGE_EXTENSION . '?s=1');
    }
}

require_once('_header.php');
?>

<!-- register form -->
<div class="span9 page_sidebar contactForm">
    <?php
    if (isErrors())
    {
        echo outputErrors();
    }
    elseif (isSuccess())
    {
        echo outputSuccess();
    }
    ?>
    <div class="well">
        <p>
            <?php echo t('contact_intro_text', 'Please fill out the following contact form to contact us.'); ?>
        </p>

        <form method="post" action="http://<?php echo _CONFIG_SITE_FULL_URL; ?>/contact.<?php echo SITE_CONFIG_PAGE_EXTENSION; ?>" class="form">

            <div class="fiftyPercent">
                <label for="name">
                    <?php echo t("your_name", "Your Name"); ?>:
                </label>
                <input type="text" tabindex="1" value="<?php echo isset($name) ? safeOutputToScreen($name) : ''; ?>" id="name" name="name">
            </div>

            <div class="fiftyPercentLast">
                <label for="emailAddress">
                    <?php echo t("email_address", "email address"); ?>:
                </label>
                <input type="text" tabindex="2" value="<?php echo isset($emailAddress) ? safeOutputToScreen($emailAddress) : ''; ?>" id="emailAddress" name="emailAddress">
            </div>
            <div class="clear"></div>
            
            <div>
                <label for="yourMessage">
                    <?php echo t("your_message", "Your Message"); ?>:
                </label>
                <textarea tabindex="3" id="query" name="query" rows="5" style="width: 96%;"><?php echo isset($query) ? safeOutputToScreen($query) : ''; ?></textarea>
            </div>
            <div class="clear"></div>
            
            <?php if(SITE_CONFIG_SHOW_CAPTCHA_ON_CONTACT_FORM == 'yes'): ?>
            <div class="thirdLast">
                <label for="recaptcha_response_field">
                    <span class="field-name"><?php echo t("confirm_text", "Confirmation Text"); ?></span>
                </label>
                <div>
                    <?php echo outputCaptcha(); ?>
                </div>
                <div class="clear"></div>
            </div>
            <div class="clear"></div>
            <?php endif; ?>

            <div class="buttonWrapper">
                <button type="submit" name="submit" class="btn btn-primary" tabindex="99"><?php echo t("submit", "submit"); ?></button>
            </div>

            <input type="hidden" value="1" name="submitme"/>
        </form>
        <div class="clear"></div>
    </div>
</div>

<?php include_once("_bannerRightContent.inc.php"); ?>
<div class="clear"><!-- --></div>


<?php
require_once('_footer.php');
?>