<?php

error_reporting(E_ALL);
/* setup includes */
require_once('includes/master.inc.php');

if (SITE_CONFIG_ENABLE_STATS != "yes")
{
    /* if no stats, redirect to homepage */
    redirect(WEB_ROOT . "/index." . SITE_CONFIG_PAGE_EXTENSION);
}

/* setup page */
define("PAGE_NAME", t("stats_page_name"));
define("PAGE_DESCRIPTION", t("stats_meta_description"));
define("PAGE_KEYWORDS", t("stats_meta_keywords"));

/* load url details */
if ($_REQUEST['url'])
{
    $shortUrlObj = shortUrl::loadByUrl(str_replace(array("!", "~s"), "", $_REQUEST['url']));
}
else
{
    /* if no short url found, redirect to home page */
    redirect(WEB_ROOT . "/index." . SITE_CONFIG_PAGE_EXTENSION);
}

// make sure user is permitted to view stats
if ($shortUrlObj->canViewStats() == false)
{
    $errorMsg = t("stats_error_url_statistics_are_private", "Statistics for this url are not publicly viewable.");
    redirect(WEB_ROOT . "/error." . SITE_CONFIG_PAGE_EXTENSION . "?e=" . urlencode($errorMsg));
}

require_once('_header.php');
?>

<script src="<?php echo WEB_ROOT; ?>/js/charts/Chart.js"></script>
<script>
    $=jQuery;
    $(document).ready(function($) {
        showChart('visitorChart2');
        
        <?php
        // last 24 hours chart
        $last24hours = charts::createBarChart($shortUrlObj, 'last24hours');
        echo $last24hours['chartJS'];
        
        // last 7 days chart
        $last7days = charts::createBarChart($shortUrlObj, 'last7days');
        echo $last7days['chartJS'];
        
        // last 30 days chart
        $last30days = charts::createBarChart($shortUrlObj, 'last30days');
        echo $last30days['chartJS'];
        
        // last 12 months chart
        $last12months = charts::createBarChart($shortUrlObj, 'last12months');
        echo $last12months['chartJS'];
        
        // top countries pie
        $countries = charts::createPieChart($shortUrlObj, 'countries');
        echo $countries['chartJS'];
        
        // top referrers pie
        $referrers = charts::createPieChart($shortUrlObj, 'referrers');
        echo $referrers['chartJS'];
        
        // top browsers pie
        $browsers = charts::createPieChart($shortUrlObj, 'browsers');
        echo $browsers['chartJS'];
        
        // top os pie
        $os = charts::createPieChart($shortUrlObj, 'os');
        echo $os['chartJS'];
        ?>
                
        resizeCharts();
    });
    
    function showChart(chartId)
    {
        $('.chart').hide();
        $('.link_selected').removeClass('link_selected');
        $('#'+chartId).fadeIn();
        $('#link_'+chartId).addClass('link_selected');
        
        return false;
    }
    
    function resizeCharts()
    {
        // This will execute whenever the window is resized
        newHeight = $(window).height();
        newWidth = $(window).width();
        
        barWidth = 870;
        barHeight = 350;
        if((newWidth < 1232) && ($('.span9').width() > 0))
        {
            barWidth = $('.span9').width();
            barHeight = Math.round(newWidth/50)+250;
        }
        
        // update charts
        $('.barChartWrapper canvas').width(barWidth);
        $('.barChartWrapper canvas').height(barHeight);
    }
    
    $(window).resize(function() {
        resizeCharts();
    });
</script>

<div class="span12 statsWrapper">
    <div class="blog_item">
        <div class="blog_head">
            <div class="date">
                <h6><i class="icon-signal icon-white"></i> <?php echo $shortUrlObj->visits; ?> <?php echo $shortUrlObj->visits == 1 ? t("visit", "visit") : t("visits", "visits"); ?></h6>
            </div>
            <h3><a href="<?php echo $shortUrlObj->compileShortUrl(); ?>" target="_blank"><?php echo str_replace("http://", "", $shortUrlObj->compileShortUrl()); ?></a></h3>
            
            <div class="meta">
                <span class="last-item"><b><?php echo t("created_"); ?></b> <?php echo dater($shortUrlObj->dateCreated); ?></span>
            </div>
        </div>
    </div>
</div>
<div class="clear" style="padding-top: 12px;"></div>

<div class="span3 page_sidebar">
    <div class="well">
        <a href="<?php echo $shortUrlObj->compileShortUrl(); ?>" target="_blank"><?php echo generateUrlThumbnail($shortUrlObj->fullUrl, '240', '180', '1280'); ?></a>
    </div>
    <div class="well">
        <h5><?php echo t('select_report', 'select report'); ?></h5>
        <hr>
        <div class="textwidget">
            <ul class="sub-menu">
                <li><a href="#" onClick="return showChart('visitorChart1');"><?php echo t("visitors"); ?></a>
                    <ul>
                        <li><a href="#" id="link_visitorChart1" onClick="return showChart('visitorChart1');"><?php echo t("last_24_hours"); ?></a></li>
                        <li><a href="#" id="link_visitorChart2" onClick="return showChart('visitorChart2');"><?php echo t("last_7_days"); ?></a></li>
                        <li><a href="#" id="link_visitorChart3" onClick="return showChart('visitorChart3');"><?php echo t("last_30_days"); ?></a></li>
                        <li><a href="#" id="link_visitorChart4" onClick="return showChart('visitorChart4');"><?php echo t("last_12_months"); ?></a></li>
                    </ul>
                </li>
                <li><a href="#" id="link_countryChart" onClick="return showChart('countryChart');"><?php echo t("countries"); ?></a></li>
                <li><a href="#" id="link_referChart" onClick="return showChart('referChart');"><?php echo t("top_referrers"); ?></a></li>
                <li><a href="#" id="link_browserChart" onClick="return showChart('browserChart');"><?php echo t("browsers"); ?></a></li>
                <li><a href="#" id="link_osChart" onClick="return showChart('osChart');"><?php echo t("operating_systems"); ?></a></li>
            </ul>
        </div>
    </div>
</div>
<div class="span9 statsWrapper">
    <div class="blog_item">
        <div class="row">
            <div class="span9">
                <div id="visitorChart1" style="display:none;" class="chart">
                    <?php echo $last24hours['canvasHTML']; ?>
                    <div> 
                        <?php echo $last24hours['dataTableHTML']; ?>
                    </div>
                </div>

                <div id="visitorChart2" style="display:none;" class="chart">
                    <?php echo $last7days['canvasHTML']; ?>
                    <div> 
                        <?php echo $last7days['dataTableHTML']; ?>
                    </div>
                </div>

                <div id="visitorChart3" style="display:none;" class="chart">
                    <?php echo $last30days['canvasHTML']; ?>
                    <div> 
                        <?php echo $last30days['dataTableHTML']; ?>
                    </div>
                </div>

                <div id="visitorChart4" style="display:none;" class="chart">
                    <?php echo $last12months['canvasHTML']; ?>
                    <div> 
                        <?php echo $last12months['dataTableHTML']; ?>
                    </div>
                </div>

                <div id="countryChart" class="chart">
                    <?php echo $countries['canvasHTML']; ?>
                    <div> 
                        <?php echo $countries['dataTableHTML']; ?>
                    </div>
                </div>

                <div id="referChart" class="chart">
                    <?php echo $referrers['canvasHTML']; ?>
                    <div> 
                        <?php echo $referrers['dataTableHTML']; ?>
                    </div>
                </div>

                <div id="browserChart" class="chart">
                    <?php echo $browsers['canvasHTML']; ?>
                    <div> 
                        <?php echo $browsers['dataTableHTML']; ?>
                    </div>
                </div>

                <div id="osChart" class="chart">
                    <?php echo $os['canvasHTML']; ?>
                    <div> 
                        <?php echo $os['dataTableHTML']; ?>
                    </div>
                </div>
            </div>
        </div>
        <hr>
    </div>
</div>

<?php
require_once('_footer.php');
?>